==> zio-aws-ssoadmin_3-5.17.267.6-sources.jar: zio/aws/ssoadmin/model/AccountAssignment.scala <==
package zio.aws.ssoadmin.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.ssoadmin.model.primitives.{
  PrincipalId,
  PermissionSetArn,
  AccountId
}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class AccountAssignment(
    accountId: Optional[AccountId] = Optional.Absent,
    permissionSetArn: Optional[PermissionSetArn] = Optional.Absent,
    principalType: Optional[zio.aws.ssoadmin.model.PrincipalType] =
      Optional.Absent,
    principalId: Optional[PrincipalId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssoadmin.model.AccountAssignment = {
    import AccountAssignment.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssoadmin.model.AccountAssignment
      .builder()
      .optionallyWith(
        accountId.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.accountId)
      .optionallyWith(
        permissionSetArn.map(value =>
          PermissionSetArn.unwrap(value): java.lang.String
        )
      )(_.permissionSetArn)
      .optionallyWith(principalType.map(value => value.unwrap))(_.principalType)
      .optionallyWith(
        principalId.map(value => PrincipalId.unwrap(value): java.lang.String)
      )(_.principalId)
      .build()
  }
  def asReadOnly: zio.aws.ssoadmin.model.AccountAssignment.ReadOnly =
    zio.aws.ssoadmin.model.AccountAssignment.wrap(buildAwsValue())
}
object AccountAssignment {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssoadmin.model.AccountAssignment
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssoadmin.model.AccountAssignment =
      zio.aws.ssoadmin.model.AccountAssignment(
        accountId.map(value => value),
        permissionSetArn.map(value => value),
        principalType.map(value => value),
        principalId.map(value => value)
      )
    def accountId: Optional[AccountId]
    def permissionSetArn: Optional[PermissionSetArn]
    def principalType: Optional[zio.aws.ssoadmin.model.PrincipalType]
    def principalId: Optional[PrincipalId]
    def getAccountId: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getPermissionSetArn: ZIO[Any, AwsError, PermissionSetArn] =
      AwsError.unwrapOptionField("permissionSetArn", permissionSetArn)
    def getPrincipalType
        : ZIO[Any, AwsError, zio.aws.ssoadmin.model.PrincipalType] =
      AwsError.unwrapOptionField("principalType", principalType)
    def getPrincipalId: ZIO[Any, AwsError, PrincipalId] =
      AwsError.unwrapOptionField("principalId", principalId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssoadmin.model.AccountAssignment
  ) extends zio.aws.ssoadmin.model.AccountAssignment.ReadOnly {
    override val accountId: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.accountId())
      .map(value => zio.aws.ssoadmin.model.primitives.AccountId(value))
    override val permissionSetArn: Optional[PermissionSetArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.permissionSetArn())
        .map(value => zio.aws.ssoadmin.model.primitives.PermissionSetArn(value))
    override val principalType: Optional[zio.aws.ssoadmin.model.PrincipalType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.principalType())
        .map(value => zio.aws.ssoadmin.model.PrincipalType.wrap(value))
    override val principalId: Optional[PrincipalId] = zio.aws.core.internal
      .optionalFromNullable(impl.principalId())
      .map(value => zio.aws.ssoadmin.model.primitives.PrincipalId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssoadmin.model.AccountAssignment
  ): zio.aws.ssoadmin.model.AccountAssignment.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ssoadmin_3-6.20.162.1-sources.jar: zio/aws/ssoadmin/model/AccountAssignment.scala <==
package zio.aws.ssoadmin.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.ssoadmin.model.primitives.{
  PrincipalId,
  PermissionSetArn,
  AccountId
}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class AccountAssignment(
    accountId: Optional[AccountId] = Optional.Absent,
    permissionSetArn: Optional[PermissionSetArn] = Optional.Absent,
    principalId: Optional[PrincipalId] = Optional.Absent,
    principalType: Optional[zio.aws.ssoadmin.model.PrincipalType] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssoadmin.model.AccountAssignment = {
    import AccountAssignment.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssoadmin.model.AccountAssignment
      .builder()
      .optionallyWith(
        accountId.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.accountId)
      .optionallyWith(
        permissionSetArn.map(value =>
          PermissionSetArn.unwrap(value): java.lang.String
        )
      )(_.permissionSetArn)
      .optionallyWith(
        principalId.map(value => PrincipalId.unwrap(value): java.lang.String)
      )(_.principalId)
      .optionallyWith(principalType.map(value => value.unwrap))(_.principalType)
      .build()
  }
  def asReadOnly: zio.aws.ssoadmin.model.AccountAssignment.ReadOnly =
    zio.aws.ssoadmin.model.AccountAssignment.wrap(buildAwsValue())
}
object AccountAssignment {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssoadmin.model.AccountAssignment
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssoadmin.model.AccountAssignment =
      zio.aws.ssoadmin.model.AccountAssignment(
        accountId.map(value => value),
        permissionSetArn.map(value => value),
        principalId.map(value => value),
        principalType.map(value => value)
      )
    def accountId: Optional[AccountId]
    def permissionSetArn: Optional[PermissionSetArn]
    def principalId: Optional[PrincipalId]
    def principalType: Optional[zio.aws.ssoadmin.model.PrincipalType]
    def getAccountId: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getPermissionSetArn: ZIO[Any, AwsError, PermissionSetArn] =
      AwsError.unwrapOptionField("permissionSetArn", permissionSetArn)
    def getPrincipalId: ZIO[Any, AwsError, PrincipalId] =
      AwsError.unwrapOptionField("principalId", principalId)
    def getPrincipalType
        : ZIO[Any, AwsError, zio.aws.ssoadmin.model.PrincipalType] =
      AwsError.unwrapOptionField("principalType", principalType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssoadmin.model.AccountAssignment
  ) extends zio.aws.ssoadmin.model.AccountAssignment.ReadOnly {
    override val accountId: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.accountId())
      .map(value => zio.aws.ssoadmin.model.primitives.AccountId(value))
    override val permissionSetArn: Optional[PermissionSetArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.permissionSetArn())
        .map(value => zio.aws.ssoadmin.model.primitives.PermissionSetArn(value))
    override val principalId: Optional[PrincipalId] = zio.aws.core.internal
      .optionalFromNullable(impl.principalId())
      .map(value => zio.aws.ssoadmin.model.primitives.PrincipalId(value))
    override val principalType: Optional[zio.aws.ssoadmin.model.PrincipalType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.principalType())
        .map(value => zio.aws.ssoadmin.model.PrincipalType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssoadmin.model.AccountAssignment
  ): zio.aws.ssoadmin.model.AccountAssignment.ReadOnly = new Wrapper(impl)
}
